@@ -1,5 +1,5 @@
 /* tpb - program to use the IBM ThinkPad(tm) special keys
- * Copyright (C) 2002 Markus Braun <markus.braun@krawel.de>
+ * Copyright (C) 2002,2003 Markus Braun <markus.braun@krawel.de>
  *
  * This file is part of tpb.
  *
@@ -24,19 +24,22 @@
 #if ENABLE_NLS
 #include <libintl.h>
 #define _(String) gettext (String)
-#else
+#else /* ENABLE_NLS */
 #define _(String) (String)
-#endif
+#endif /* ENABLE_NLS */
 
 enum state {UNDEFINED = -1, STATE_OFF, STATE_ON, STATE_AUTO};
 enum mode {MODE_COMMENT, MODE_INDENT, MODE_KEYWORD, MODE_SEPARATOR, MODE_ARGUMENT, MODE_END};
 
 /* configuration defaults */
+#define DEFAULT_DAEMON STATE_OFF
 #define DEFAULT_APM STATE_OFF
 #define DEFAULT_POWERMGT STATE_AUTO
+#define DEFAULT_XEVENTS STATE_ON
 #define DEFAULT_VERBOSE STATE_OFF
 #define DEFAULT_POLLTIME 1000
 #define DEFAULT_NVRAMDEV "/dev/nvram"
+#define DEFAULT_NVRAMDEV_DEVFS "/dev/misc/nvram"
 #define DEFAULT_MIXER STATE_OFF
 #define DEFAULT_MIXERSTEPS 14
 #define DEFAULT_MIXERDEV "/dev/mixer"
@@ -47,6 +50,9 @@ enum mode {MODE_COMMENT, MODE_INDENT, MODE_KEYWORD, MODE_SEPARATOR, MODE_ARGUMEN
 #define DEFAULT_OSDCOLOR "BLUE"
 #define DEFAULT_OSDTIMEOUT 3
 #define DEFAULT_OSDSHADOW 2
+#define DEFAULT_OSDSHADOWCOLOR "BLACK"
+#define DEFAULT_OSDOUTLINE 1
+#define DEFAULT_OSDOUTLINECOLOR "BLACK"
 #define DEFAULT_OSDVERTICAL 25
 #define DEFAULT_OSDHORIZONTAL 25
 #define DEFAULT_OSDPOS XOSD_bottom
@@ -56,9 +62,9 @@ enum mode {MODE_COMMENT, MODE_INDENT, MODE_KEYWORD, MODE_SEPARATOR, MODE_ARGUMEN
 /* configuration files */
 #ifdef SYSCONFDIR
 #define GLOBAL_CONFIG_FILE SYSCONFDIR "/tpbrc"
-#else
+#else /* SYSCONFDIR */
 #define GLOBAL_CONFIG_FILE "/etc/tpbrc"
-#endif
+#endif /* SYSCONFDIR */
 #define PRIVATE_CONFIG_FILE ".tpbrc"
 
 /* Keywords in configuration file */
@@ -69,12 +75,21 @@ enum mode {MODE_COMMENT, MODE_INDENT, MODE_KEYWORD, MODE_SEPARATOR, MODE_ARGUMEN
 #define CFG_POWERMGT_ON "on"
 #define CFG_POWERMGT_OFF "off"
 #define CFG_POWERMGT_AUTO "auto"
+#define CFG_XEVENTS "xevents"
+#define CFG_XEVENTS_ON "on"
+#define CFG_XEVENTS_OFF "off"
 #define CFG_NVRAM "nvram"
 #define CFG_POLLTIME "polltime"
 #define CFG_THINKPAD "thinkpad"
 #define CFG_HOME "home"
 #define CFG_SEARCH "search"
 #define CFG_MAIL "mail"
+#define CFG_FAVORITES "favorites"
+#define CFG_RELOAD "reload"
+#define CFG_ABORT "abort"
+#define CFG_BACKWARD "backward"
+#define CFG_FORWARD "forward"
+#define CFG_FN "fn"
 #define CFG_CALLBACK "callback"
 #define CFG_MIXER "mixer"
 #define CFG_MIXER_ON "on"
@@ -87,6 +102,11 @@ enum mode {MODE_COMMENT, MODE_INDENT, MODE_KEYWORD, MODE_SEPARATOR, MODE_ARGUMEN
 #define CFG_OSDTIMEOUT "osdtimeout"
 #define CFG_OSDOFFSET "osdoffset"
 #define CFG_OSDSHADOW "osdshadow"
+#if HAVE_LIBXOSD_VERSION >= 20200
+#define CFG_OSDSHADOWCOLOR "osdshadowcolor"
+#define CFG_OSDOUTLINE "osdoutline"
+#define CFG_OSDOUTLINECOLOR "osdoutlinecolor"
+#endif /* HAVE_LIBXOSD_VERSION */
 #define CFG_OSDVERTICAL "osdvertical"
 #define CFG_OSDHORIZONTAL "osdhorizontal"
 #define CFG_OSDPOS "osdpos"
@@ -105,44 +125,56 @@ enum mode {MODE_COMMENT, MODE_INDENT, MODE_KEYWORD, MODE_SEPARATOR, MODE_ARGUMEN
 #define BUFFER_SIZE 256
 
 typedef struct {
-	int daemon;
-	int apm;
-	int powermgt;
-	char *nvram;
-	int polltime;
-	char *tpbcmd;
-	char *homecmd;
-	char *searchcmd;
-	char *mailcmd;
-	char *callback;
-	int mixer;
-	int mixersteps;
-	char *mixerdev;
-	int verbose;
+  int daemon;
+  int apm;
+  int powermgt;
+  int xevents;
+  char *nvram;
+  int polltime;
+  char *tpb_cmd;
+  char *home_cmd;
+  char *search_cmd;
+  char *mail_cmd;
+  char *favorites_cmd;
+  char *reload_cmd;
+  char *abort_cmd;
+  char *backward_cmd;
+  char *forward_cmd;
+  char *fn_cmd;
+  char *callback;
+  int mixer;
+  int mixersteps;
+  char *mixerdev;
+  int verbose;
 #ifdef HAVE_LIBXOSD
-	int osd;
-	char *osdfont;
-	char *osdcolor;
-	int osdtimeout;
-	int osdshadow;
-	int osdvertical;
-	int osdhorizontal;
-	xosd_pos osdpos;
-#ifndef HAVE_LIBXOSD0
-	xosd_align osdalign;
-#endif /* HAVE_LIBXOSD0 */
+  int osd;
+  char *osdfont;
+  char *osdcolor;
+  int osdtimeout;
+  int osdshadow;
+#if HAVE_LIBXOSD_VERSION >= 20200
+  char *osdshadowcolor;
+  int osdoutline;
+  char *osdoutlinecolor;
+#endif /* HAVE_LIBXOSD_VERSION */
+  int osdvertical;
+  int osdhorizontal;
+  xosd_pos osdpos;
+#if HAVE_LIBXOSD_VERSION >= 10000
+  xosd_align osdalign;
+#endif /* HAVE_LIBXOSD_VERSION */
 #endif /* HAVE_LIBXOSD */
 } config;
 
-int parse_cfg_file(char *name);
-void init_cfg(void);
+int parse_cfg_file(config *cfg, char *name);
+void parse_option(config *cfg, int argc, char **argv);
+void init_cfg(config *cfg);
 void clear_cfg(config *cfg);
-void override_cfg(config *master);
+void free_cfg(config *cfg);
+void override_cfg(config *master, config *slave);
 void set_value(char *key, char *arg, config *cfg);
-void parse_option(int argc, char **argv);
 void print_usage(const char *prog);
 
 #endif /* __CFG_H__ */
 
-/* vim:set sw=2:set ts=2: */
 /* vim600:set fen:set fdm=marker:set fdl=0: */
